import { convertFactory } from '@graphql-codegen/visitor-plugin-common';
import { print } from 'graphql/language/printer';
function _gql(operationDefinitionNode, noGraphQLTag = false) {
    if (noGraphQLTag) {
        const documentNode = { kind: 'Document', definitions: [operationDefinitionNode] };
        return JSON.stringify(documentNode, (k, v) => (k === 'loc' ? undefined : v), 2);
    }
    else {
        const code = print(operationDefinitionNode)
            .replace(/^/gm, '  ')
            .replace(/\s*$/, '');
        return ['gql`', code, '`'].join('\n');
    }
}
export const plugin = (schema, documents, config) => {
    const { namingConvention, namePrefix = '', nameSuffix = '', noGraphQLTag = false, transformUnderscore = false } = config;
    const convertFn = convertFactory({ namingConvention });
    const content = documents
        .filter(documentFile => documentFile.filePath.length > 0)
        .map(documentFile => documentFile.content.definitions
        .filter((d) => d.name && d.name.value)
        .map((d) => {
        const name = convertFn(namePrefix + d.name.value + nameSuffix, { transformUnderscore });
        return 'export const ' + name + ': DocumentNode = ' + _gql(d, noGraphQLTag) + ';\n';
    })
        .join('\n'))
        .join('\n');
    const prepend = [];
    if (content) {
        prepend.push(`import { DocumentNode } from 'graphql';`);
        if (!noGraphQLTag) {
            prepend.push(`import gql from 'graphql-tag';`);
        }
        prepend.push('', '');
    }
    return prepend.join('\n') + content;
};
export const validate = async (schema, documents, config, outputFile) => {
    if (!outputFile.endsWith('.ts')) {
        throw new Error(`Plugin "typescript-document-nodes" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map