import { PluginFunction, PluginValidateFn } from '@graphql-codegen/plugin-helpers';
export declare type NamingConvention = 'lowerCamelCase' | 'UpperCamelCase' | 'UPPER_CASE';
export interface TypeScriptDocumentNodesPluginConfig {
    /**
     * @name namingConvention
     * @type string
     * @default false
     * @description Generates variable names in choosen naming convention
     * (lowerCamelCase, UpperCamelCase or UPPER_CASE)
     *
     * @example
     * ```yml
     *  generates: src/api/user-service/queries.ts
     *  documents: src/api/user-service/queries.graphql
     *  plugins:
     *    - graphql-codegen-typescript-document-nodes
     *  config:
     *    namingConvention: lowerCamelCase
     * ```
     */
    namingConvention?: NamingConvention;
    /**
     * @name namePrefix
     * @type string
     * @default ''
     * @description Adds prefix to the name
     *
     * @example
     * ```yml
     *  generates: src/api/user-service/queries.ts
     *  documents: src/api/user-service/queries.graphql
     *  plugins:
     *    - graphql-codegen-typescript-document-nodes
     *  config:
     *    namePrefix: 'gql'
     * ```
     */
    namePrefix?: string;
    /**
     * @name nameSuffix
     * @type string
     * @default ''
     * @description Adds suffix to the name
     *
     * @example
     * ```yml
     *  generates: src/api/user-service/queries.ts
     *  documents: src/api/user-service/queries.graphql
     *  plugins:
     *    - graphql-codegen-typescript-document-nodes
     *  config:
     *    nameSuffix: 'Query'
     * ```
     */
    nameSuffix?: string;
}
export declare const plugin: PluginFunction<TypeScriptDocumentNodesPluginConfig>;
export declare const validate: PluginValidateFn<any>;
