import { print } from 'graphql/language/printer';
function upperFirst(str) {
    return str[0].toUpperCase() + str.slice(1);
}
function camelize(str) {
    return str
        .replace(/([a-z])([A-Z])/g, '$1 $2')
        .split(/[\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/)
        .reduce((result, word, index) => {
        word = word.toLowerCase();
        return result + (index ? upperFirst(word) : word);
    }, '');
}
function upperize(str) {
    return str
        .replace(/([a-z])([A-Z])/g, '$1 $2')
        .replace(/[\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g, '_')
        .toUpperCase();
}
function useNamingConvention(str, namingConvention) {
    if (namingConvention === 'lowerCamelCase') {
        return camelize(str);
    }
    else if (namingConvention === 'UpperCamelCase') {
        return upperFirst(camelize(str));
    }
    else if (namingConvention === 'UPPER_CASE') {
        return upperize(str);
    }
    else {
        return str;
    }
}
export const plugin = (schema, documents, config) => {
    const { namingConvention, namePrefix = '', nameSuffix = '' } = config;
    const content = documents
        .filter(documentFile => documentFile.filePath.length > 0)
        .map(documentFile => documentFile.content.definitions
        .filter((d) => d.name && d.name.value)
        .map((d) => {
        const name = useNamingConvention(namePrefix + d.name.value + nameSuffix, namingConvention);
        const code = print(d)
            .replace(/^/gm, '  ')
            .replace(/\s*$/, '');
        return ['export const ' + name + ': DocumentNode = gql`', code, '`;', ''].join('\n');
    })
        .join('\n'))
        .join('\n');
    const prepend = content ? ["import { DocumentNode } from 'graphql';", "import gql from 'graphql-tag';", '', ''] : [];
    return prepend.join('\n') + content;
};
export const validate = async (schema, documents, config, outputFile) => {
    if (!outputFile.endsWith('.ts')) {
        throw new Error(`Plugin "typescript-document-nodes" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map